==> koha-3.02.05.tar.gz: koha-3.2.5/installer/data/mysql/it-IT/necessari/userpermissions.sql <==
SET FOREIGN_KEY_CHECKS=0;

INSERT INTO permissions (module_bit, code, description) VALUES
   ( 1, 'circulate_remaining_permissions', 'Permessi rimanenti per la circolazione'),
   ( 1, 'override_renewals', 'Sblocca i rinnovi bloccati'),
   ( 6, 'place_holds', 'Fai prenotazioni per gli utenti'),
   ( 6, 'modify_holds_priority', 'Modifica priorità prenotazioni'),
   ( 9, 'edit_catalogue', 'Cataloga (crea/modifica dati bibliografici e di copia)'),
   ( 9, 'fast_cataloging', 'Catalogazione veloce'),
   ( 9, 'edit_items', 'Crea/modifica copie'),
   (11, 'vendors_manage', 'Crea/modifica fornitori'),
   (11, 'contracts_manage', 'Crea/modifica contratti'),
   (11, 'period_manage', 'Gestisci scadenze budgets'),
   (11, 'budget_manage', 'Crea/modifica budgets'),
   (11, 'budget_modify', 'Modifica budget (non li crea ma modifica gli esistenti)'),
   (11, 'planning_manage', 'Intervieni sulla pianificazione dei budgets'),
   (11, 'order_manage', 'Gestisci ordini e raccoglitori'),
   (11, 'group_manage', 'Gestisci ordini e raccoglitori raggruppati'),
   (11, 'order_receive', 'Gestisci arrivi'),
   (11, 'budget_add_del', 'Aggiungi e cancella budgets (senza modificarli)'),
   (13, 'edit_news', 'Scrivi le news per l\'OPAC e per l\'interfaccia staff'),
   (13, 'label_creator', 'Crea etichette da stampare e barcodes dal catalogo e dai dati degli utenti'),
   (13, 'edit_calendar', 'Definisci i giorni di chiusura della biblioteca'),
   (13, 'moderate_comments', 'Modera i commenti degli utenti'),
   (13, 'edit_notices', 'Definisci gli avvisi'),
   (13, 'edit_notice_status_triggers', 'Imposta il messaggio o lo stato degli avvisi per le copie in ritardo'),
   (13, 'view_system_logs', 'Scorri i log di sistema'),
   (13, 'inventory', 'Lavora sugli inventari (stocktaking) del tuo catalogo'),
   (13, 'stage_marc_import', 'Opera sui Record MARC presenti nella zona di lavoro'),
   (13, 'manage_staged_marc', 'Gestisci i record MARC in lavorazione, inclusi il completare e il cancellare gli import'),
   (13, 'export_catalog', 'Esporta i dati bibliografici e di copia'),
   (13, 'import_patrons', 'Importa i dati utente'),
   (13, 'delete_anonymize_patrons', 'Cancella i vecchi prestiti e rendi anonimo lo storico della circolazione (canella in lettura lo storico utenti prestito)'),
   (13, 'batch_upload_patron_images', 'Aggiorna le foto utente in modalità batch o al momento'),
   (13, 'schedule_tasks', 'Schedula i task da far andare'),
   (13, 'items_batchmod', 'Perform batch modification of items'),
   (13, 'items_batchdel', 'Perform batch deletion of items'),
   (13, 'manage_csv_profiles', 'Gestisci i profili CSV di export'),
   (13, 'moderate_tags', 'Modera i tag inseriti dagli utenti'),
   (13, 'rotating_collections', 'Gestisci le collezioni circolanti (rotating collections)'),
   (15, 'check_expiration', 'Controlla la scadenza di una risora in continuazione'),
   (15, 'claim_serials', 'Richiedi i fascicoli non arrivati'),
   (15, 'create_subscription', 'Crea un nuovo abbonamento'),
   (15, 'delete_subscription', 'Cancella un abbonamento esistente'),
   (15, 'edit_subscription', 'Modifica un abbonamento esistente'),
   (15, 'receive_serials', 'Ricevi fascicoli'),
   (15, 'renew_subscription', 'Rinnova un abbonamento'),
   (15, 'routing', 'Crea/Manipola liste di distribuzione dei fascicoli ( routing list)'),
   (16, 'execute_reports', 'Esegui reports SQL'),
   (16, 'create_reports', 'Crea reports SQL')
;
SET FOREIGN_KEY_CHECKS=1;

==> koha-3.08.18.tar.gz: koha-3.08.18/installer/data/mysql/it-IT/necessari/userpermissions.sql <==
SET FOREIGN_KEY_CHECKS=0;

INSERT INTO permissions (module_bit, code, description) VALUES
   ( 1, 'circulate_remaining_permissions', 'Permessi rimanenti per la circolazione'),
   ( 1, 'override_renewals', 'Sblocca i rinnovi bloccati'),
   ( 6, 'place_holds', 'Fai prenotazioni per gli utenti'),
   ( 6, 'modify_holds_priority', 'Modifica priorità prenotazioni'),
   ( 9, 'edit_catalogue', 'Cataloga (crea/modifica dati bibliografici e di copia)'),
   ( 9, 'fast_cataloging', 'Catalogazione veloce'),
   ( 9, 'edit_items', 'Crea/modifica copie'),
   (11, 'vendors_manage', 'Crea/modifica fornitori'),
   (11, 'contracts_manage', 'Crea/modifica contratti'),
   (11, 'period_manage', 'Gestisci scadenze budgets'),
   (11, 'budget_manage', 'Crea/modifica budgets'),
   (11, 'budget_modify', 'Modifica budget (non li crea ma modifica gli esistenti)'),
   (11, 'planning_manage', 'Intervieni sulla pianificazione dei budgets'),
   (11, 'order_manage', 'Gestisci ordini e raccoglitori'),
   (11, 'group_manage', 'Gestisci ordini e raccoglitori raggruppati'),
   (11, 'order_receive', 'Gestisci arrivi'),
   (11, 'budget_add_del', 'Aggiungi e cancella budgets (senza modificarli)'),
   (13, 'edit_news', 'Scrivi le news per l\'OPAC e per l\'interfaccia staff'),
   (13, 'label_creator', 'Crea etichette da stampare e barcodes dal catalogo e dai dati degli utenti'),
   (13, 'edit_calendar', 'Definisci i giorni di chiusura della biblioteca'),
   (13, 'moderate_comments', 'Modera i commenti degli utenti'),
   (13, 'edit_notices', 'Definisci le notifiche'),
   (13, 'edit_notice_status_triggers', 'Imposta il messaggio o lo stato delle notifiche per le copie in ritardo'),
   (13, 'view_system_logs', 'Scorri i log di sistema'),
   (13, 'inventory', 'Lavora sugli inventari (stocktaking) del tuo catalogo'),
   (13, 'stage_marc_import', 'Opera sui Record MARC presenti nella zona di lavoro'),
   (13, 'manage_staged_marc', 'Gestisci i record MARC in lavorazione, inclusi il completare e il cancellare gli import'),
   (13, 'export_catalog', 'Esporta i dati bibliografici e di copia'),
   (13, 'import_patrons', 'Importa i dati utente'),
   (13, 'delete_anonymize_patrons', 'Cancella i vecchi prestiti e rendi anonimo lo storico della circolazione (canella in lettura lo storico utenti prestito)'),
   (13, 'batch_upload_patron_images', 'Aggiorna le foto utente in modalità batch o al momento'),
   (13, 'schedule_tasks', 'Schedula i task da far andare'),
   (13, 'items_batchmod', 'Perform batch modification of items'),
   (13, 'items_batchdel', 'Perform batch deletion of items'),
   (13, 'manage_csv_profiles', 'Gestisci i profili CSV di export'),
   (13, 'moderate_tags', 'Modera i tag inseriti dagli utenti'),
   (13, 'rotating_collections', 'Gestisci le collezioni circolanti (rotating collections)'),
   (13, 'upload_local_cover_images', 'Carica copertine in locale'),
   (15, 'check_expiration', 'Controlla la scadenza di una risora in continuazione'),
   (15, 'claim_serials', 'Richiedi i fascicoli non arrivati'),
   (15, 'create_subscription', 'Crea un nuovo abbonamento'),
   (15, 'delete_subscription', 'Cancella un abbonamento esistente'),
   (15, 'edit_subscription', 'Modifica un abbonamento esistente'),
   (15, 'receive_serials', 'Ricevi fascicoli'),
   (15, 'renew_subscription', 'Rinnova un abbonamento'),
   (15, 'routing', 'Crea/Manipola liste di distribuzione dei fascicoli ( routing list)'),
   (16, 'execute_reports', 'Esegui reports SQL'),
   (16, 'create_reports', 'Crea reports SQL')
;
SET FOREIGN_KEY_CHECKS=1;
